Documentation
¶
Index ¶
- Variables
- func CleanValue(val interface{}) interface{}
- func FormatContent(v interface{}) string
- func Method(method ...string) []string
- func NewStaticHandle(prefixAndRoot ...string) http.Handler
- func PrepareResponse(request *Request, rule *Rule, result interface{}) interface{}
- func RunRoute(request *Request, rule *Rule, params ...[]*parameter) interface{}
- type Closure
- type Compiled
- type Config
- type Cookie
- type CookieConfig
- type CookieMiddleware
- type CorsConfig
- type CorsHandlerdeprecated
- type CorsMiddleware
- type File
- type Handler
- func NewCookieMiddleware(cfg ...*CookieConfig) Handler
- func NewCorsHandler(config ...CorsConfig) Handlerdeprecated
- func NewCorsMiddleware(config ...CorsConfig) Handler
- func NewRecoverHandler(debug bool) Handlerdeprecated
- func NewRecoverMiddleware(debug bool) Handler
- func NewRouteHandler(r Router) Handlerdeprecated
- func NewRouteMiddleware(r Router) Handler
- func NewSessionMiddleware(cfg *Config) Handler
- func NewTrimStringsHandler(except ...string) Handlerdeprecated
- func NewTrimStringsMiddleware(except ...string) Handler
- func NewValidateSignatureHandler(r ...Router) Handlerdeprecated
- func NewValidateSignatureMiddleware(r ...Router) Handler
- type HandlerFunc
- type Manager
- type Middleware
- type Option
- type Param
- type ParameterResolver
- type ParameterResolverFunc
- type ParameterizedMiddleware
- type Params
- type Pipeline
- type RecoverHandlerdeprecated
- type RecoverMiddleware
- type Request
- func (r *Request) All(keys ...string) map[string]string
- func (r *Request) AllFiles() (map[string]*File, error)
- func (r *Request) BearerToken() string
- func (r *Request) Boolean(key string, defaultValue ...bool) bool
- func (r *Request) ClientIP() string
- func (r *Request) Context() context.Context
- func (r *Request) Cookie(key string, value ...string) (string, error)
- func (r *Request) Except(keys ...string) map[string]string
- func (r *Request) Exists(keys ...string) bool
- func (r *Request) ExpectsJson() bool
- func (r *Request) File(key string) (*File, error)
- func (r *Request) Filled(keys ...string) bool
- func (r *Request) Fingerprint() string
- func (r *Request) Float(key string, defaultValue ...float64) float64
- func (r *Request) FullUrl() string
- func (r *Request) FullUrlWithQuery(query map[string]string) string
- func (r *Request) FullUrlWithoutQuery(keys ...string) string
- func (r *Request) Get(key string) (value interface{}, exists bool)
- func (r *Request) GetContent() ([]byte, error)
- func (r *Request) GetHttpRequest() *http.Request
- func (r *Request) GetMethod() string
- func (r *Request) GetPath() string
- func (r *Request) GetRouteParam(key string, defaultValue ...string) string
- func (r *Request) Has(keys ...string) bool
- func (r *Request) HasAny(keys ...string) bool
- func (r *Request) HasFile(key string) bool
- func (r *Request) Header(key string) string
- func (r *Request) Input(key string, value ...string) (string, error)
- func (r *Request) Integer(key string, defaultValue ...int) int
- func (r *Request) Is(patterns ...string) bool
- func (r *Request) IsAjax() bool
- func (r *Request) IsMethod(m string) bool
- func (r *Request) Merge(values map[string]string) *Request
- func (r *Request) Method() string
- func (r *Request) Missing(keys ...string) bool
- func (r *Request) Only(keys ...string) map[string]string
- func (r *Request) Path() string
- func (r *Request) Post(key string, value ...string) (string, error)
- func (r *Request) Query(key string, value ...string) (string, error)
- func (r *Request) ResponseWriter() http.ResponseWriter
- func (r *Request) RouteIs(patterns ...string) bool
- func (r *Request) RouteMiddlewares() []interface{}
- func (r *Request) RouteParam(key string, defaultValue ...string) (string, error)
- func (r *Request) Segment(index int, defaultValue ...string) string
- func (r *Request) Segments() []string
- func (r *Request) Session() session.Session
- func (r *Request) Set(key string, value interface{})
- func (r *Request) SetCookieHandler(handler *Cookie)
- func (r *Request) SetResponseWriter(w http.ResponseWriter) *Request
- func (r *Request) SetRouteMiddlewares(middlewares []interface{})
- func (r *Request) SetRouteParam(name, value string)
- func (r *Request) SetSession(s session.Session)
- func (r *Request) Url() string
- func (r *Request) UserAgent() string
- func (r *Request) WantsJson() bool
- func (r *Request) WithContext(ctx context.Context) *Request
- type Response
- func Download(filePath string, filename ...string) *Response
- func DownloadResponse(filePath string, filename ...string) *Response
- func ErrorResponse() *Response
- func FileResponse(filepath string) *Response
- func HandledResponse() *Response
- func Html(s string) *Response
- func Json(v interface{}) *Response
- func MakeResponse(v interface{}) *Response
- func NewResponse() *Response
- func NoContent(status ...int) *Response
- func NotFoundResponse() *Response
- func Redirect(to string, status ...int) *Response
- func StreamDownload(streamFunc func(w io.Writer) bool, filename string) *Response
- func StreamResponse(streamFunc func(w io.Writer) bool) *Response
- func Text(s string) *Response
- func (r *Response) Cookie(name interface{}, params ...interface{}) error
- func (r *Response) GetCharset() string
- func (r *Response) GetCode() int
- func (r *Response) GetContent() string
- func (r *Response) GetContentType() string
- func (r *Response) GetCookies() map[string]*http.Cookie
- func (r *Response) IsHandled() bool
- func (r *Response) Send(w http.ResponseWriter)
- func (r *Response) SetCharset(val string) *Response
- func (r *Response) SetCode(val int) *Response
- func (r *Response) SetContent(val string) *Response
- func (r *Response) SetContentType(val string) *Response
- func (r *Response) SetCookieHandler(handler *Cookie) *Response
- func (r *Response) SetFile(filepath string) *Response
- func (r *Response) SetRequest(req *Request) *Response
- func (r *Response) SetStream(streamFunc func(w io.Writer) bool) *Response
- type Route
- func (r *Route) Add(method []string, pattern string, handler interface{}) Router
- func (r *Route) AddRule(rule *Rule) *Rule
- func (r *Route) AliasMiddleware(name string, middleware interface{}) Router
- func (r *Route) Any(pattern string, handler interface{}) Router
- func (r *Route) CurrentRouteName(req *Request) string
- func (r *Route) Delete(pattern string, handler interface{}) Router
- func (r *Route) Dispatch(request *Request) interface{}
- func (r *Route) Dump() []byte
- func (r *Route) Fallback(handler interface{})
- func (r *Route) Get(pattern string, handler interface{}) Router
- func (r *Route) GetMiddlewareGroup(name string) []interface{}
- func (r *Route) GetRouteMiddleware(name string) interface{}
- func (r *Route) Group(callback func(group Router))
- func (r *Route) Has(name string) bool
- func (r *Route) HasValidSignature(req *Request) bool
- func (r *Route) Head(pattern string, handler interface{}) Router
- func (r *Route) Is(req *Request, patterns ...string) bool
- func (r *Route) Match(request *Request) (*Rule, []*parameter, error)
- func (r *Route) MatchRequest(request *Request) (*Rule, []*parameter, error)
- func (r *Route) Middleware(middlewares ...interface{}) Router
- func (r *Route) MiddlewareGroup(name string, middlewares ...interface{}) Router
- func (r *Route) Name(name string) Router
- func (r *Route) Options(pattern string, handler interface{}) Router
- func (r *Route) Patch(pattern string, handler interface{}) Router
- func (r *Route) Pattern(name string, expression string)
- func (r *Route) Post(pattern string, handler interface{}) Router
- func (r *Route) Prefix(prefix string) Router
- func (r *Route) Put(pattern string, handler interface{}) Router
- func (r *Route) Register()
- func (r *Route) SignedUrl(name string, expiration time.Duration, params map[string]string) string
- func (r *Route) Static(path, root string)
- func (r *Route) Statics(statics map[string]string)
- func (r *Route) Url(name string, params map[string]string) string
- func (r *Route) Where(name string, expression string) Router
- func (r *Route) WhereAlpha(names ...string) Router
- func (r *Route) WhereIn(name string, allowed []string) Router
- func (r *Route) WhereNumber(names ...string) Router
- type RouteHandlerdeprecated
- type RouteMiddleware
- type RouteRequest
- type Router
- type Rule
- func (r *Rule) Bind(req *Request, path string, treeParams ...[]*parameter) []*parameter
- func (r *Rule) GatherRouteMiddleware() []interface{}
- func (r *Rule) Matches(method, path string) bool
- func (r *Rule) Middleware(middlewares ...interface{}) *Rule
- func (r *Rule) Run(request *Request, params ...[]*parameter) (result interface{})
- func (r *Rule) ValidateParams(params []*parameter) bool
- type SessionMiddleware
- type Terminable
- type TrimStringsHandlerdeprecated
- type TrimStringsMiddleware
- type ValidateSignatureHandlerdeprecated
- type ValidateSignatureMiddleware
Constants ¶
This section is empty.
Variables ¶
var HandleException func(err interface{}) *Response
--- Begin recover.go ---
var ResolveSignatureKey func() string
Functions ¶
func CleanValue ¶
func CleanValue(val interface{}) interface{}
CleanValue recursively trims strings in nested maps and slices.
func FormatContent ¶
func FormatContent(v interface{}) string
func NewStaticHandle ¶
NewStaticHandle A Handler responds to a Static HTTP request.
func PrepareResponse ¶
PrepareResponse Create a response instance from the given value.
Types ¶
type Config ¶
type Config struct {
// Default Session Driver
Driver string
CookieName string
// Session Lifetime
Lifetime time.Duration
// Session Encryption
Encrypt bool
// Session File Location
Files string
}
--- Begin manager.go ---
func DefaultSessionConfig ¶
func DefaultSessionConfig() *Config
DefaultSessionConfig returns the default session configuration.
type Cookie ¶
type Cookie struct {
Config *CookieConfig
}
func ParseCookieHandler ¶
func ParseCookieHandler(cfg ...*CookieConfig) *Cookie
ParseCookieHandler returns a Cookie instance with given or default configuration.
type CookieConfig ¶
type CookieConfig struct {
Prefix string
Path string // optional
Domain string // optional
ExpiresDuration time.Duration // Expiration duration configuration
RawExpires string // for reading cookies only
MaxAge int
Secure bool
HttpOnly bool
Raw string
Unparsed []string
}
--- Begin cookie.go ---
func DefaultCookieConfig ¶
func DefaultCookieConfig() *CookieConfig
DefaultCookieConfig returns a new default CookieConfig.
type CookieMiddleware ¶
type CookieMiddleware struct {
// contains filtered or unexported fields
}
CookieMiddleware manages Cookie configuration for incoming requests and outgoing responses.
type CorsConfig ¶
type CorsConfig struct {
AllowOrigins []string
AllowMethods []string
AllowHeaders []string
ExposeHeaders []string
AllowCredentials bool
MaxAge int
}
--- Begin cors.go --- CorsConfig defines the configuration options for CORS middleware.
func DefaultCorsConfig ¶
func DefaultCorsConfig() CorsConfig
DefaultCorsConfig returns standard default CORS configuration.
type CorsHandler
deprecated
type CorsHandler = CorsMiddleware
Deprecated: Use CorsMiddleware instead.
type CorsMiddleware ¶
type CorsMiddleware struct {
// contains filtered or unexported fields
}
func (*CorsMiddleware) Process ¶
func (h *CorsMiddleware) Process(req *Request, next Closure) interface{}
type Handler ¶
Handler Middleware Handler interface
func NewCookieMiddleware ¶
func NewCookieMiddleware(cfg ...*CookieConfig) Handler
NewCookieMiddleware creates a new CookieMiddleware with the given configuration.
func NewCorsHandler
deprecated
func NewCorsHandler(config ...CorsConfig) Handler
Deprecated: Use NewCorsMiddleware instead.
func NewCorsMiddleware ¶
func NewCorsMiddleware(config ...CorsConfig) Handler
NewCorsMiddleware creates a new CORS middleware.
func NewRecoverHandler
deprecated
func NewRecoverMiddleware ¶
NewRecoverMiddleware creates a new panic recovery middleware.
func NewRouteHandler
deprecated
func NewRouteMiddleware ¶
NewRouteMiddleware creates a new route dispatcher middleware.
func NewSessionMiddleware ¶
NewSessionMiddleware creates a new session management middleware with the specified configuration.
func NewTrimStringsHandler
deprecated
func NewTrimStringsMiddleware ¶
NewTrimStringsMiddleware creates a new parameter trimming middleware.
func NewValidateSignatureHandler
deprecated
func NewValidateSignatureMiddleware ¶
NewValidateSignatureMiddleware creates a new URL signature validation middleware.
type HandlerFunc ¶
HandlerFunc type is an adapter to allow the use of ordinary functions as HTTP middleware.
type Manager ¶
type Manager struct {
Config *Config
// contains filtered or unexported fields
}
func NewManager ¶
type Middleware ¶
--- Begin middleware.go --- Middleware Handle an incoming request.
type Option ¶
type Option func(*Route)
Option defines a functional configuration option for Route.
func WithParameterResolver ¶
func WithParameterResolver(resolver ParameterResolver) Option
WithParameterResolver configures a custom parameter resolver for route handler invocation.
func WithSignatureKey ¶
WithSignatureKey sets the secret HMAC key for signed URLs.
type ParameterResolver ¶
type ParameterResolver interface {
ResolveParameter(paramType reflect.Type, request *Request) (reflect.Value, bool)
}
ParameterResolver defines the interface to resolve route handler parameters by type.
type ParameterResolverFunc ¶
ParameterResolverFunc is an adapter to allow the use of ordinary functions as ParameterResolver.
func (ParameterResolverFunc) ResolveParameter ¶
func (f ParameterResolverFunc) ResolveParameter(paramType reflect.Type, request *Request) (reflect.Value, bool)
ResolveParameter calls f(paramType, request).
type ParameterizedMiddleware ¶
type ParameterizedMiddleware func(params ...string) Middleware
ParameterizedMiddleware Handle an incoming request with parameters.
type Pipeline ¶
type Pipeline struct {
// contains filtered or unexported fields
}
func (*Pipeline) ServeHTTP ¶
func (p *Pipeline) ServeHTTP(w http.ResponseWriter, r *http.Request)
ServeHTTP Implement http.Handler safely
func (*Pipeline) ThenReturn ¶
ThenReturn runs the pipeline and returns the result
type RecoverHandler
deprecated
type RecoverHandler = RecoverMiddleware
Deprecated: Use RecoverMiddleware instead.
type RecoverMiddleware ¶
type RecoverMiddleware struct {
// contains filtered or unexported fields
}
func (*RecoverMiddleware) Process ¶
func (h *RecoverMiddleware) Process(req *Request, next Closure) (result interface{})
Process Process the request to a router and return the response.
type Request ¶
type Request struct {
Request *http.Request
CookieHandler *Cookie
// contains filtered or unexported fields
}
--- Begin request.go --- Request HTTP request
func NewRequest ¶
NewRequest create a new HTTP request from *http.Request
func (*Request) BearerToken ¶
BearerToken returns the Bearer token from the Authorization header.
func (*Request) Exists ¶
Exists Determine if the request contains a given input item key (alias of Has).
func (*Request) ExpectsJson ¶
ExpectsJson returns true if the request expects a JSON response.
func (*Request) Filled ¶
Filled Determine if the request contains a non-empty value for an input item.
func (*Request) Fingerprint ¶
Fingerprint gets a unique fingerprint for the request.
func (*Request) FullUrlWithQuery ¶
FullUrlWithQuery appends or replaces query parameters to current full URL.
func (*Request) FullUrlWithoutQuery ¶
FullUrlWithoutQuery removes specified query parameters from current full URL.
func (*Request) GetContent ¶
GetContent Returns the request body content.
func (*Request) GetHttpRequest ¶
GetHttpRequest get Current *http.Request
func (*Request) GetRouteParam ¶
GetRouteParam gets a route parameter
func (*Request) Has ¶
Has Determine if the request contains a given input item key (including empty strings).
func (*Request) Missing ¶
Missing Determine if the given input key is completely missing from the request.
func (*Request) ResponseWriter ¶
func (r *Request) ResponseWriter() http.ResponseWriter
ResponseWriter returns the native http.ResponseWriter associated with this request.
func (*Request) RouteMiddlewares ¶
func (r *Request) RouteMiddlewares() []interface{}
RouteMiddlewares Returns the route middlewares matched for the request.
func (*Request) RouteParam ¶
RouteParam returns a route parameter with error if not present
func (*Request) SetCookieHandler ¶
SetCookieHandler sets the Cookie handler for the request.
func (*Request) SetResponseWriter ¶
func (r *Request) SetResponseWriter(w http.ResponseWriter) *Request
SetResponseWriter sets the native http.ResponseWriter for direct writing.
func (*Request) SetRouteMiddlewares ¶
func (r *Request) SetRouteMiddlewares(middlewares []interface{})
SetRouteMiddlewares Sets the route middlewares matched for the request.
func (*Request) SetRouteParam ¶
SetRouteParam sets a route parameter by name
func (*Request) SetSession ¶
Session set the session associated with the request.
type Response ¶
type Response struct {
Request *Request
CookieHandler *Cookie
Header *http.Header
// contains filtered or unexported fields
}
--- Begin response.go ---
func DownloadResponse ¶
DownloadResponse Create a new HTTP Download Response
func ErrorResponse ¶
func ErrorResponse() *Response
NotFoundResponse Create a new HTTP Error Response
func FileResponse ¶
FileResponse Create a response that serves a file
func HandledResponse ¶
func HandledResponse() *Response
HandledResponse creates a response indicating that output was directly handled.
func MakeResponse ¶
func MakeResponse(v interface{}) *Response
MakeResponse Create a new HTTP Response by auto detecting content type
func NotFoundResponse ¶
func NotFoundResponse() *Response
NotFoundResponse Create a new HTTP NotFoundResponse
func StreamDownload ¶
StreamDownload creates a new streaming download response.
func StreamResponse ¶
StreamResponse creates a new streaming HTTP Response.
func (*Response) GetCharset ¶
GetContentType get the Charset on the response.
func (*Response) GetContent ¶
GetCode get the response content.
func (*Response) GetContentType ¶
GetContentType get the Content-Type on the response.
func (*Response) GetCookies ¶
GetCookies returns the response cookies map.
func (*Response) Send ¶
func (r *Response) Send(w http.ResponseWriter)
Send Sends HTTP headers and content.
func (*Response) SetCharset ¶
GetContentType sets the Charset on the response.
func (*Response) SetContent ¶
SetContent sets the content on the response.
func (*Response) SetContentType ¶
GetContentType sets the Content-Type on the response.
func (*Response) SetCookieHandler ¶
SetCookieHandler sets the Cookie handler for the response.
func (*Response) SetRequest ¶
SetRequest bind original request for file serving
type Route ¶
type Route struct {
// contains filtered or unexported fields
}
func (*Route) AliasMiddleware ¶
AliasMiddleware registers a route-specific middleware alias.
func (*Route) CurrentRouteName ¶
CurrentRouteName returns the current route name for the request.
func (*Route) Fallback ¶
func (r *Route) Fallback(handler interface{})
Fallback registers a fallback route.
func (*Route) GetMiddlewareGroup ¶
GetMiddlewareGroup retrieves a registered middleware group.
func (*Route) GetRouteMiddleware ¶
GetRouteMiddleware retrieves a registered middleware alias.
func (*Route) HasValidSignature ¶
HasValidSignature checks if the given request has a valid signature.
func (*Route) Match ¶
Match Find the first rule matching a given request using Radix Tree with fallback.
func (*Route) MatchRequest ¶
MatchRequest Dispatch the request to find a matching rule
func (*Route) Middleware ¶
Middleware Set the middleware attached to the route.
func (*Route) MiddlewareGroup ¶
MiddlewareGroup defines a named middleware group.
func (*Route) WhereAlpha ¶
WhereAlpha adds an alphabetic regex constraint to parameters.
func (*Route) WhereNumber ¶
WhereNumber adds a numeric regex constraint to parameters.
type RouteHandler
deprecated
type RouteHandler = RouteMiddleware
Deprecated: Use RouteMiddleware instead.
type RouteMiddleware ¶
type RouteMiddleware struct {
Router Router
}
--- Begin route.go ---
func (*RouteMiddleware) Process ¶
func (h *RouteMiddleware) Process(request *Request, next Closure) interface{}
Process Process the request to a router and return the response.
type RouteRequest ¶
type Router ¶
type Router interface {
// Add registers a new route.
Add(method []string, pattern string, handler interface{}) Router
// Get registers a GET route.
Get(pattern string, handler interface{}) Router
// Post registers a POST route.
Post(pattern string, handler interface{}) Router
// Put registers a PUT route.
Put(pattern string, handler interface{}) Router
// Patch registers a PATCH route.
Patch(pattern string, handler interface{}) Router
// Delete registers a DELETE route.
Delete(pattern string, handler interface{}) Router
// Options registers an OPTIONS route.
Options(pattern string, handler interface{}) Router
// Any registers a route responding to all standard verbs.
Any(pattern string, handler interface{}) Router
// Group creates a route group.
Group(callback func(group Router))
// Prefix adds a prefix to the current route group.
Prefix(prefix string) Router
// Middleware adds middleware to the current route or group.
Middleware(middlewares ...interface{}) Router
// Dispatch resolves the request to a handler and executes it.
Dispatch(request *Request) interface{}
// Name names the route.
Name(name string) Router
// Url generates a URL for a named route.
Url(name string, params map[string]string) string
// Fallback registers a fallback route.
Fallback(handler interface{})
// Where adds a regex constraint to a route parameter.
Where(name string, expression string) Router
// WhereNumber adds a numeric regex constraint to parameters.
WhereNumber(names ...string) Router
// WhereAlpha adds an alphabetic regex constraint to parameters.
WhereAlpha(names ...string) Router
// WhereIn adds an allowed values constraint to a parameter.
WhereIn(name string, allowed []string) Router
// Has determines if the route collection contains a given named route.
Has(name string) bool
// CurrentRouteName returns the current route name for the request.
CurrentRouteName(req *Request) string
// Is determines if the current route's name matches given patterns.
Is(req *Request, patterns ...string) bool
// Register compiles and indexes the collected route rules into the Radix Tree.
Register()
// Dump returns a byte slice dump of all registered route rules.
Dump() []byte
// SignedUrl creates a signed URL for a named route.
SignedUrl(name string, expiration time.Duration, params map[string]string) string
// HasValidSignature determines if the request has a valid signature.
HasValidSignature(req *Request) bool
// AliasMiddleware registers a route-specific middleware alias.
AliasMiddleware(name string, middleware interface{}) Router
// MiddlewareGroup defines a named middleware group.
MiddlewareGroup(name string, middlewares ...interface{}) Router
// GetRouteMiddleware retrieves a registered middleware alias.
GetRouteMiddleware(name string) interface{}
// GetMiddlewareGroup retrieves a registered middleware group.
GetMiddlewareGroup(name string) []interface{}
}
--- Begin router.go --- Router defines the interface for the routing system.
type Rule ¶
type Rule struct {
Compiled *Compiled
// contains filtered or unexported fields
}
--- Begin rule.go --- Rule Route rule
func (*Rule) Bind ¶
Bind Bind the router parameters to a given request and return parsed parameters.
func (*Rule) GatherRouteMiddleware ¶
func (r *Rule) GatherRouteMiddleware() []interface{}
GatherRouteMiddleware Get all middleware, including the ones from the controller.
func (*Rule) Middleware ¶
Middleware Set the middleware attached to the rule.
func (*Rule) ValidateParams ¶
ValidateParams checks if given parameters satisfy where constraints
type SessionMiddleware ¶
type SessionMiddleware struct {
Manager *Manager
}
--- Begin middleware_session.go ---
func (*SessionMiddleware) Process ¶
func (h *SessionMiddleware) Process(req *Request, next Closure) interface{}
type Terminable ¶
Terminable Terminable Middleware interface
type TrimStringsHandler
deprecated
type TrimStringsHandler = TrimStringsMiddleware
Deprecated: Use TrimStringsMiddleware instead.
type TrimStringsMiddleware ¶
type TrimStringsMiddleware struct {
// contains filtered or unexported fields
}
--- Begin trim.go ---
func (*TrimStringsMiddleware) Process ¶
func (h *TrimStringsMiddleware) Process(req *Request, next Closure) interface{}
type ValidateSignatureHandler
deprecated
type ValidateSignatureHandler = ValidateSignatureMiddleware
Deprecated: Use ValidateSignatureMiddleware instead.
type ValidateSignatureMiddleware ¶
type ValidateSignatureMiddleware struct {
// contains filtered or unexported fields
}
--- Begin validate_signature.go ---
func (*ValidateSignatureMiddleware) Process ¶
func (h *ValidateSignatureMiddleware) Process(req *Request, next Closure) interface{}